@@ -232,8 +232,8 @@ def test_inversion_more_complicated_with_max_levels():
     assert data_decoded == expected
 
 
-def get_round_trip_decoded(stats=False):
-    encoder = OneHotEncoder({'animal': 2, 'color': 1}, ['weight', 'height'])
+def get_round_trip_decoded(stats=False, omit_cols=None):
+    encoder = OneHotEncoder({'animal': 2, 'color': 1}, ['weight', 'height'], omit_cols=omit_cols)
 
     data = [{'animal': 'cat', 'color': 'blue', 'weight': 6.0, 'height': 88.9, 'extra_junk': 'blah'},
             {'animal': 'cat', 'color': 'red', 'weight': 3.0, 'height': 44.9},
@@ -276,7 +276,8 @@ def test_inversion_more_complicated_with_max_levels_diff():
                         'numeric_cols': ['weight', 'height'],
                         'categorical_n_levels_dict': {'animal': 2, 'color': 1},
                         'one_hot_encoder_dicts': {'animal': {'cat': 0, 'mouse': 1}, 'color': {'blue': 0}},
-                        'numeric_stats': None}
+                        'numeric_stats': None,
+                        'omit_cols': None}
 
     assert packaged == package_expected
 
@@ -302,7 +303,34 @@ def test_inversion_more_complicated_w_max_levels_diff_and_numeric_stats():
                         'numeric_cols': ['weight', 'height'],
                         'categorical_n_levels_dict': {'animal': 2, 'color': 1},
                         'one_hot_encoder_dicts': {'animal': {'cat': 0, 'mouse': 1}, 'color': {'blue': 0}},
-                        'numeric_stats': stats}
+                        'numeric_stats': stats,
+                        'omit_cols': None}
+
+    assert packaged == package_expected
+
+
+def test_inversion_with_omit_cols():
+    data_decoded, packaged = get_round_trip_decoded(stats=True, omit_cols=['color'])
+
+    decoded_expected = [{'height': 88.9, 'weight': 6.0, 'animal': 'cat'},
+                        {'height': 44.9, 'weight': 3.0, 'animal': 'cat'},
+                        {'height': 2.5, 'weight': 5.5, 'animal': 'UNKNOWN_CATEGORICAL_LEVEL'},
+                        {'height': 3233.2, 'weight': 7.0, 'animal': 'UNKNOWN_CATEGORICAL_LEVEL'},
+                        {'height': 666.6, 'weight': 2.0, 'animal': 'cat'},
+                        {'height': 55.5, 'weight': 0.0, 'animal': 'mouse'},
+                        {'height': 33, 'weight': 99.9, 'animal': 'mouse'}]
+
+    assert data_decoded == decoded_expected
+
+    stats = {'weight': {'min': 0.0, 'max': 99.9, 'mean': 17.62857142857143, 'median': 5.5},
+             'height': {'min': 2.5, 'max': 3233.2, 'mean': 589.2285714285715, 'median': 55.5}}
+
+    package_expected = {'max_levels_default': 10000,
+                        'numeric_cols': ['weight', 'height'],
+                        'categorical_n_levels_dict': {'animal': 2, 'color': 1},
+                        'one_hot_encoder_dicts': {'animal': {'cat': 0, 'mouse': 1}, 'color': {'blue': 0}},
+                        'numeric_stats': stats,
+                        'omit_cols': ['color']}
 
     assert packaged == package_expected
 
@@ -325,7 +353,8 @@ def test_html_form():
                 'numeric_cols': ['weight', 'height'],
                 'categorical_n_levels_dict': {'animal': 2, 'color': 1},
                 'one_hot_encoder_dicts': {'animal': {'cat': 0, 'mouse': 1}, 'color': {'blue': 0}},
-                'numeric_stats': None}
+                'numeric_stats': None,
+                'omit_cols': None}
 
     assert package == expected
 
